@@ -2,7 +2,6 @@
 #include "PhoneNumberValidator.h"
 
 #include <QDesktopServices>
-
 #include <iostream>
 using namespace std;
 
@@ -111,13 +110,18 @@ MainWindow::log (const QString &strText, int level /*= 10*/)
         strDisp = strText;
     }
 
+    if ((strDisp.contains ("password", Qt::CaseInsensitive)) ||
+        ((!strPass.isEmpty ()) &&
+         (strDisp.contains (strPass, Qt::CaseInsensitive)))) {
+        strDisp = "Log message with password blocked";
+    }
+
     QDateTime dt = QDateTime::currentDateTime ();
     QString strLog = QString("%1 : %2 : %3")
                      .arg(dt.toString ("yyyy-MM-dd hh:mm:ss.zzz"))
                      .arg(level)
                      .arg(strDisp);
 
-
     // Send to standard output
     cout << strLog.toStdString () << endl;
 
@@ -336,6 +340,16 @@ MainWindow::init ()
         &dlgSMS, SIGNAL (sendSMS (const QStringList &, const QString &)),
          this  , SLOT   (sendSMS (const QStringList &, const QString &)));
 
+    // Status from contacts object
+    QObject::connect (&oContacts, SIGNAL (status   (const QString &, int)),
+                       this     , SLOT   (setStatus(const QString &, int)));
+    // oContacts.allContacts -> this.getContactsDone
+    QObject::connect (&oContacts, SIGNAL (allContacts (bool)),
+                      this      , SLOT   (getContactsDone (bool)));
+    // Status from inbox object
+    QObject::connect (&oInbox, SIGNAL (status   (const QString &, int)),
+                       this  , SLOT   (setStatus(const QString &, int)));
+
     // Additional UI initializations:
     //@@UV: Need this for later
 //    ui->edNumber->setValidator (new PhoneNumberValidator (ui->edNumber));
@@ -389,8 +403,7 @@ MainWindow::init ()
          this       , SLOT(onVmailPlayerStateChanged(QMediaPlayer::State)));
 
     // If the cache has the username and password, begin login
-    if (dbMain.getUserPass (strUser, strPass))
-    {
+    if (dbMain.getUserPass (strUser, strPass)) {
         this->setUsername (strUser);
         this->setPassword (strPass);
 
@@ -398,9 +411,7 @@ MainWindow::init ()
         logoutCompleted (true, l);
         // Login without popping up the "enter user/pass" dialog
         doLogin ();
-    }
-    else
-    {
+    } else {
         // Show this status for 60 seconds (or until the next status)
         setStatus ("Please enter email and password", 60 * 1000);
 
@@ -728,14 +739,6 @@ MainWindow::getContactsDone (bool bOk)
 void
 MainWindow::initContacts ()
 {
-    // Status
-    QObject::connect (&oContacts, SIGNAL (status   (const QString &, int)),
-                       this     , SLOT   (setStatus(const QString &, int)));
-
-    // oContacts.allContacts -> this.getContactsDone
-    QObject::connect (&oContacts, SIGNAL (allContacts (bool)),
-                      this      , SLOT   (getContactsDone (bool)));
-
     oContacts.setUserPass (strUser, strPass);
     oContacts.loginSuccess ();
     oContacts.initModel (this);
@@ -752,11 +755,6 @@ MainWindow::deinitContacts ()
 void
 MainWindow::initInbox ()
 {
-    // Status
-    QObject::connect (
-            &oInbox, SIGNAL (status   (const QString &, int)),
-            this   , SLOT   (setStatus(const QString &, int)));
-
     oInbox.loginSuccess ();
     oInbox.initModel (this);
     oInbox.refresh ();
